#
# spec file for package thinkfan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%if 0%{?suse_version} < 1550 && 0%{?sle_version} <= 150300
# systemd-rpm-macros is wrong in 15.3 and below
%define _modprobedir /lib/modprobe.d
%endif
%global modprobe_d_files 50-thinkfan.conf

Name:           thinkfan
Version:        1.3.1
Release:        3.4
Summary:        A minimalist fan control program
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            https://github.com/vmatare/thinkfan/
Source0:        %{name}-%{version}.tar.bz2
Source1:        thinkfan-sysconfig
Patch1:         thinkfan-systemd.patch
Patch2:         harden_thinkfan-sleep.service.patch
Patch3:         harden_thinkfan-wakeup.service.patch
Patch4:         harden_thinkfan.service.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libatasmart-devel
BuildRequires:  yaml-cpp-devel
BuildRequires:  pkgconfig(systemd)

%description
A simple fan control program. Read temperatures, check them against configured
limits and switch to appropriate (also pre-configured) fan level.
Requires a working thinkpad_acpi or any other hwmon driver
that enables temperature reading and fan control from userspace.

Don't forget to set the desired temperature values in %{_sysconfdir}/thinkfan.conf

%prep
%setup -q
%autopatch -p1

%build
%cmake -DUSE_ATASMART:BOOL=ON -DCMAKE_BUILD_TYPE:STRING=Release
%make_build CFLAGS="%{optflags}"

%install
%cmake_install
rm -rf %{buildroot}%{_datadir}/doc/%{name}

mkdir -p %{buildroot}/%{_sysconfdir}
install -D -m0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.%{name}
rm -rf %{buildroot}%{_sysconfdir}/systemd/system/thinkfan.service.d

cp examples/%{name}.yaml %{buildroot}/%{_sysconfdir}/%{name}.yaml

mkdir -p %{buildroot}/%{_unitdir}
cp -v rcscripts/systemd/*.service %{buildroot}/%{_unitdir}/
sed -i "s|%{_prefix}/local/sbin|%{_sbindir}|g" %{buildroot}/%{_unitdir}/*

mkdir -p %{buildroot}%{_modprobedir}
echo "options thinkpad_acpi fan_control=1" > %{buildroot}%{_modprobedir}/50-thinkfan.conf

%pre
%service_add_pre %{name}.service
%service_add_pre %{name}-sleep.service
%service_add_pre %{name}-wakeup.service
# Avoid restoring outdated stuff in posttrans
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -f "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}.rpmsave.old" || :
done

%post
%service_add_post %{name}.service
%service_add_post %{name}-sleep.service
%service_add_post %{name}-wakeup.service
%{fillup_only %{name}}

%preun
%service_del_preun %{name}.service
%service_del_preun %{name}-sleep.service
%service_del_preun %{name}-wakeup.service

%postun
%service_del_postun %{name}.service
%service_del_postun %{name}-sleep.service
%service_del_postun %{name}-wakeup.service

%posttrans
# Migration of modprobe.conf files to _modprobedir
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -fv "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}" || :
done

%files
%license COPYING
%doc README.md examples/* COPYING
%dir %{_modprobedir}
%{_sbindir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}.yaml
%{_modprobedir}/50-thinkfan.conf
%{_fillupdir}/sysconfig.%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man5/thinkfan.conf.5%{?ext_man}
%{_mandir}/man5/thinkfan.conf.legacy.5%{?ext_man}
%{_unitdir}/*.service

%changelog
* Mon Feb 19 2024 Maciej Borzecki <maciek.borzecki@gmail.com>
- Add COPYING to %%doc
* Fri Mar  4 2022 Martin Wilck <mwilck@suse.com>
- Install modprobe.conf files to %%_modprobedir (bsc#1196275, jsc#SLE-20639)
* Wed Feb 23 2022 maciek.borzecki@gmail.com
- Update to version 1.3.1:
  * systemd: put version in service description
  * Revert "get version from git --describe"
  * Revert "CI: check version file is up to date"
  * CI: check version file is up to date
  * get version from git --describe
  * fully parameterize version
  * clean up std:: namespace usage
* Mon Jan  3 2022 Johannes Segitz <jsegitz@suse.com>
- Removed ProtectKernelTunables from the hardenings. Changed
  * harden_thinkfan-sleep.service.patch
  * harden_thinkfan-wakeup.service.patch
  * harden_thinkfan.service.patch
* Wed Nov 24 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_thinkfan-sleep.service.patch
  * harden_thinkfan-wakeup.service.patch
  * harden_thinkfan.service.patch
* Wed Nov 17 2021 Maciej Borzecki <maciek.borzecki@gmail.com>
- Spec cleanup for submission to openSUSE:Factory
* Tue Nov 16 2021 maciek.borzecki@gmail.com
- Update to version 1.3.0:
  * CI: switch to Ubuntu 18.04 and 20.04
  * yamlconfig: fix fan init on separate levels: section
  * Revert correction in README
  * yamlconfig: fix multifan config
  * yamlconfig: more pointer copying for Ubuntu 16.04
  * correctly hook up refactored read_temps logic
  * yamlconfig: do toplevel parse by keyword
  * move all read_temps logic into sensors
  * split drivers.* into fans.* and sensors.*
  * fix out of bounds error in TpSensorDriver::read_temps
  * config: fail on misconfigured upper/lower limits
  * yamlconfig: error out when no fans are configured
  * rename type arg in name-based hwmon search
  * use iterators ComplexLevel::up and down
  * fix incompatibility when using libcxx
  * improve context on some YAML error messages
  * fail properly when only some hwmon indices are wrong
  * Synchronize argument options lists between manpage and help message
  * Fix minor typo in README
  * fix multiple typos in the manpages
  * install thinkfan.conf.legacy manpage
* Mon Aug 30 2021 lars@linux-schulserver.de - 1.2.2
- update to 1.2.2
  + This is a maintenance release that fixes a long-standing bug in
    handling sensors that may disappear at runtime (i.e. those
    marked with optional: true).
    An error in the logic surrounding that led to the
    optional: setting effectively being ignored.
  + The systemd service file (thinkfan-wakeup.service) that is
    responsible for notifying thinkfan when the system wakes up from
    suspend, hibernate, etc, was faulty in that it would send the
    notification just before going to sleep instead of just after
    waking up.
    In many configurations, that meant that the fans would return
    to their default behavior after wakeup.
    This release should fix that issue.
  + Sensors can now be marked as optional, so thinkfan won't fail
    if there is an error reading from them.
    Addresses issues #39, #41 and #44.
  + The thinkfan.conf manpage has been updated to thoroughly cover
    the new YAML-based config syntax. The manpage for the old
    (now deprecated) syntax was renamed to thinkfan.conf.legacy.
    The legacy config examples were completely removed, and instead
    we now have a single YAML example config that should
    cover everything.
  + Numerous minor and not-so-minor stability and compatibility issues
    have been fixed. Most importantly, on systemd-based systems, thinkfan
    will now be notified before the system goes to sleep, hopefully
    eliminating the sensor-read problems on wakeup reported by some users.
  + hwmon sensors can now be specified by name (thanks @akheron).
    See examples/thinkfan.conf.yaml.
  + thinkfan should now also reinitialize correctly after hibernate and
    hybrid-sleep (applies to systemd only).
  + The thinkfan systemd service now runs after sysinit.target, to make
    sure all kernel drivers have been loaded.
  + Some stricter warnings from newer compilers should be fixed
  + The -p option should now parse its arguments correctly (thanks @mowgli)
- added thinkfan-rpmlintrc
- use new yaml file for configuration (needs user adjustments)
- new upstream URL
- avoid systemd override.conf:
  + added thinkfan-1.2.2-systemd.patch
  + added thinkfan-sysconfig file (see /etc/sysconfig/thinkfan in
    the installed system)
* Tue Jan  2 2018 lars@linux-schulserver.de - 1.0.2
- initial package 1.0(.2) based on the work of Christoph Müller
